@@ -21,6 +21,7 @@
 */
 
 #include "iconsidepane.h"
+#include "mainwindow.h"
 #include "prefs.h"
 using namespace Kontact;
 
@@ -43,6 +44,7 @@ using namespace Kontact;
 #include <QTimer>
 #include <QCollator>
 #include <QLayout>
+#include <QPainter>
 
 namespace Kontact
 {
@@ -57,13 +59,13 @@ public:
     }
 
 public Q_SLOTS:
-    void clear() Q_DECL_OVERRIDE {
+    void clear() override {
         // Don't allow the current selection to be cleared. QListView doesn't call to this method
         // nowadays, but just to cover of future change of implementation, since QTreeView does call
         // to this one when clearing the selection.
     }
 
-    void select(const QModelIndex &index, QItemSelectionModel::SelectionFlags command) Q_DECL_OVERRIDE {
+    void select(const QModelIndex &index, QItemSelectionModel::SelectionFlags command) override {
         // Don't allow the current selection to be cleared
         if (!index.isValid() && (command & QItemSelectionModel::Clear))
         {
@@ -73,7 +75,7 @@ public Q_SLOTS:
     }
 
     void select(const QItemSelection &selection,
-                QItemSelectionModel::SelectionFlags command) Q_DECL_OVERRIDE {
+                QItemSelectionModel::SelectionFlags command) override {
         // Don't allow the current selection to be cleared
         if (!selection.count() && (command & QItemSelectionModel::Clear))
         {
@@ -98,7 +100,7 @@ public:
 
     void emitReset()
     {
-        //FIXME 
+        //FIXME
         //Q_EMIT reset();
     }
 
@@ -107,7 +109,7 @@ public:
         pluginList = list;
     }
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE
+    Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         Qt::ItemFlags flags = QStringListModel::flags(index);
 
@@ -129,7 +131,7 @@ public:
     }
 
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+                      const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent);
         if (row < 0 || row >= pluginList.count()) {
@@ -138,7 +140,7 @@ public:
         return createIndex(row, column, pluginList[row]);
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
             return QVariant();
@@ -183,7 +185,7 @@ public:
         sort(0);
     }
 protected:
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
     {
         KontactInterface::Plugin *leftPlugin =
             static_cast<KontactInterface::Plugin *>(left.internalPointer());
@@ -210,7 +212,7 @@ public:
     }
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const Q_DECL_OVERRIDE
+               const QModelIndex &index) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
             return;
@@ -218,12 +220,14 @@ public:
 
         QStyleOptionViewItem optionCopy(*static_cast<const QStyleOptionViewItem *>(&option));
         optionCopy.decorationPosition = QStyleOptionViewItem::Top;
-        optionCopy.decorationSize = QSize(mNavigator->iconSize(), mNavigator->iconSize());
+        const int height = QFontMetrics(painter->font()).height();
+        optionCopy.decorationSize =
+            mNavigator->showIcons() ? QSize(mNavigator->iconSize(), mNavigator->iconSize() + height) : QSize();
         optionCopy.textElideMode = Qt::ElideNone;
         QStyledItemDelegate::paint(painter, optionCopy, index);
     }
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
             return QSize();
@@ -231,6 +235,7 @@ public:
 
         QStyleOptionViewItem optionCopy(*static_cast<const QStyleOptionViewItem *>(&option));
         optionCopy.decorationPosition = QStyleOptionViewItem::Top;
+
         optionCopy.decorationSize =
             mNavigator->showIcons() ? QSize(mNavigator->iconSize(), mNavigator->iconSize()) : QSize();
         optionCopy.textElideMode = Qt::ElideNone;
@@ -244,7 +249,7 @@ private:
 }
 
 Navigator::Navigator(SidePaneBase *parent)
-    : QListView(parent), mSidePane(parent)
+    : QListView(parent), mSidePane(parent), mMainWindow(nullptr)
 {
     setViewport(new QWidget(this));
 
@@ -256,6 +261,7 @@ Navigator::Navigator(SidePaneBase *parent)
     mShowText = Prefs::self()->sidePaneShowText();
 
     QActionGroup *viewMode = new QActionGroup(this);
+    connect(viewMode, &QActionGroup::triggered, this, &Navigator::slotActionTriggered);
 
     mShowIconsAction = new QAction(i18nc("@action:inmenu", "Show Icons Only"), this);
     mShowIconsAction->setCheckable(true);
@@ -290,10 +296,6 @@ Navigator::Navigator(SidePaneBase *parent)
         i18nc("@info:whatsthis",
               "Choose this option if you want the sidebar items to have icons and text."));
 
-    QAction *sep = new QAction(this);
-    sep->setSeparator(true);
-    connect(viewMode, &QActionGroup::triggered, this, &Navigator::slotActionTriggered);
-
     QActionGroup *iconSize = new QActionGroup(this);
     connect(iconSize, &QActionGroup::triggered, this, &Navigator::slotActionTriggered);
 
@@ -330,9 +332,24 @@ Navigator::Navigator(SidePaneBase *parent)
         i18nc("@info:whatsthis",
               "Choose this option if you want the sidebar icons to be extra small."));
 
+    mHideSideBarAction = new QAction(i18nc("@action:inmenu", "Hide Sidebar"), this);
+    mHideSideBarAction->setCheckable(true);
+    mHideSideBarAction->setChecked(false);
+    setHelpText(mHideSideBarAction, i18nc("@info:status", "Hide the icon sidebar"));
+    mHideSideBarAction->setWhatsThis(
+                i18nc("@info:whatsthis",
+                       "Choose this option if you to hide the icon sidebar. Press F9 to unhide."));
+    connect(mHideSideBarAction, &QAction::triggered, this, &Navigator::slotHideSideBarTriggered);
+
+    QAction *sep = new QAction(this);
+    sep->setSeparator(true);
+    QAction *sep2 = new QAction(this);
+    sep2->setSeparator(true);
+
     QList<QAction *> actionList;
     actionList << mShowIconsAction << mShowTextAction << mShowBothAction << sep
-               << mBigIconsAction << mNormalIconsAction << mSmallIconsAction;
+               << mBigIconsAction << mNormalIconsAction << mSmallIconsAction << sep2
+               << mHideSideBarAction;
 
     insertActions(nullptr, actionList);
 
@@ -527,10 +544,19 @@ void Navigator::slotActionTriggered(QAction *object)
     QTimer::singleShot(0, this, &Navigator::updateNavigatorSize);
 }
 
+void Navigator::slotHideSideBarTriggered()
+{
+    if (mainWindow()) {
+        mainWindow()->showHideSideBar(false);
+        mHideSideBarAction->setChecked(false);
+    }
+}
+
 void Navigator::updateNavigatorSize()
 {
     parentWidget()->setMaximumWidth(sizeHint().width());
     parentWidget()->setMinimumWidth(sizeHint().width());
+    update();
 }
 
 IconSidePane::IconSidePane(KontactInterface::Core *core, QWidget *parent)
@@ -539,6 +565,7 @@ IconSidePane::IconSidePane(KontactInterface::Core *core, QWidget *parent)
     mNavigator = new Navigator(this);
     layout()->addWidget(mNavigator);
     mNavigator->setFocusPolicy(Qt::NoFocus);
+    mNavigator->setMainWindow(dynamic_cast<MainWindow *>(core));
     connect(mNavigator, &Navigator::pluginActivated, this, &IconSidePane::pluginSelected);
 }
 
@@ -565,4 +592,3 @@ void IconSidePane::resizeEvent(QResizeEvent *event)
 }
 
 #include "iconsidepane.moc"
-
